libcosmic/cosmic/iced/trait.Function.html

30 lines
6.8 KiB
HTML
Raw Normal View History

<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="A trait extension for binary functions (`Fn(A, B) -&#62; O`)."><title>Function in cosmic::iced - Rust</title><script>if(window.location.protocol!=="file:")document.head.insertAdjacentHTML("beforeend","SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2".split(",").map(f=>`<link rel="preload" as="font" type="font/woff2" crossorigin href="../../static.files/${f}">`).join(""))</script><link rel="stylesheet" href="../../static.files/normalize-9960930a.css"><link rel="stylesheet" href="../../static.files/rustdoc-aa0817cf.css"><meta name="rustdoc-vars" data-root-path="../../" data-static-root-path="../../static.files/" data-current-crate="cosmic" data-themes="" data-resource-suffix="" data-rustdoc-version="1.90.0-nightly (3048886e5 2025-07-30)" data-channel="nightly" data-search-js="search-fa3e91e5.js" data-settings-js="settings-5514c975.js" ><script src="../../static.files/storage-68b7e25d.js"></script><script defer src="sidebar-items.js"></script><script defer src="../../static.files/main-eebb9057.js"></script><noscript><link rel="stylesheet" href="../../static.files/noscript-32bb7600.css"></noscript><link rel="alternate icon" type="image/png" href="../../static.files/favicon-32x32-6580c154.png"><link rel="icon" type="image/svg+xml" href="../../static.files/favicon-044be391.svg"></head><body class="rustdoc trait"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="mobile-topbar"><button class="sidebar-menu-toggle" title="show sidebar"></button></nav><nav class="sidebar"><div class="sidebar-crate"><h2><a href="../../cosmic/index.html">cosmic</a><span class="version">1.0.0</span></h2></div><div class="sidebar-elems"><section id="rustdoc-toc"><h2 class="location"><a href="#">Function</a></h2><h3><a href="#required-methods">Required Methods</a></h3><ul class="block"><li><a href="#tymethod.with" title="with">with</a></li></ul><h3><a href="#dyn-compatibility">Dyn Compatibility</a></h3><h3><a href="#implementors">Implementors</a></h3></section><div id="rustdoc-modnav"><h2><a href="index.html">In cosmic::<wbr>iced</a></h2></div></div></nav><div class="sidebar-resizer" title="Drag to resize sidebar"></div><main><div class="width-limiter"><rustdoc-search></rustdoc-search><section id="main-content" class="content"><div class="main-heading"><div class="rustdoc-breadcrumbs"><a href="../index.html">cosmic</a>::<wbr><a href="index.html">iced</a></div><h1>Trait <span class="trait">Function</span><button id="copy-path" title="Copy item path to clipboard">Copy item path</button></h1><rustdoc-toolbar></rustdoc-toolbar><span class="sub-heading"></span></div><pre class="rust item-decl"><code>pub trait Function&lt;A, B, O&gt; {
// Required method
fn <a href="#tymethod.with" class="fn">with</a>(self, prefix: A) -&gt; impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/ops/function/trait.Fn.html" title="trait core::ops::function::Fn">Fn</a>(B);
}</code></pre><details class="toggle top-doc" open><summary class="hideme"><span>Expand description</span></summary><div class="docblock"><p>A trait extension for binary functions (<code>Fn(A, B) -&gt; O</code>).</p>
<p>It enables you to use a bunch of nifty functional programming paradigms
that work well with iced.</p>
</div></details><h2 id="required-methods" class="section-header">Required Methods<a href="#required-methods" class="anchor"></a></h2><div class="methods"><details class="toggle method-toggle" open><summary><section id="tymethod.with" class="method"><h4 class="code-header">fn <a href="#tymethod.with" class="fn">with</a>(self, prefix: A) -&gt; impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/ops/function/trait.Fn.html" title="trait core::ops::function::Fn">Fn</a>(B)</h4></section></summary><div class="docblock"><p>Applies the given first argument to a binary function and returns
a new function that takes the other argument.</p>
<p>This lets you partially “apply” a function—equivalent to currying,
but it only works with binary functions. If you want to apply an
arbitrary number of arguments, create a little struct for them.</p>
<h5 id="when-is-this-useful"><a class="doc-anchor" href="#when-is-this-useful"></a>When is this useful?</h5>
<p>Sometimes you will want to identify the source or target
of some message in your user interface. This can be achieved through
normal means by defining a closure and moving the identifier
inside:</p>
<div class="example-wrap"><pre class="rust rust-example-rendered"><code><span class="kw">let </span>id = <span class="number">123</span>;
element.map(<span class="kw">move </span>|result| Message::ButtonPressed(id, result))</code></pre></div>
<p>Thats quite a mouthful. <a href="trait.Function.html#tymethod.with" title="method iced_core::Function::with::with"><code>with</code></a> lets you write:</p>
<div class="example-wrap"><pre class="rust rust-example-rendered"><code><span class="kw">let </span>id = <span class="number">123</span>;
element.map(Message::ButtonPressed.with(id))</code></pre></div>
<p>Effectively creating the same closure that partially applies
the <code>id</code> to the message—but much more concise!</p>
</div></details></div><h2 id="dyn-compatibility" class="section-header">Dyn Compatibility<a href="#dyn-compatibility" class="anchor"></a></h2><div class="dyn-compatibility-info"><p>This trait is <b>not</b> <a href="https://doc.rust-lang.org/nightly/reference/items/traits.html#dyn-compatibility">dyn compatible</a>.</p><p><i>In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.</i></p></div><h2 id="implementors" class="section-header">Implementors<a href="#implementors" class="anchor"></a></h2><div id="implementors-list"><section id="impl-Function%3CA,+B,+O%3E-for-F" class="impl"><a href="#impl-Function%3CA,+B,+O%3E-for-F" class="anchor"></a><h3 class="code-header">impl&lt;F, A, B, O&gt; <a class="trait" href="trait.Function.html" title="trait cosmic::iced::Function">Function</a>&lt;A, B, O&gt; for F<div class="where">where
F: <a class="trait" href="https://doc.rust-lang.org/nightly/core/ops/function/trait.Fn.html" title="trait core::ops::function::Fn">Fn</a>(A, B) -&gt; O,
A: <a class="trait" href="https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html" title="trait core::clone::Clone">Clone</a>,</div></h3></section></div><script src="../../trait.impl/iced_core/trait.Function.js" async></script></section></div></main></body></html>